@@ -144,7 +144,7 @@ def preprocessing_training(df, industry_dictionary, state_dictionary,
                                                     model_type=model_type )
 
     df_leads_clean = utils.reduce_mem_usage_category( df=df_leads_clean )
-    df_leads_clean = utils.onehotencoding( df=df_leads_clean )
+    df_leads_clean = utils.one_hot_encoding( df=df_leads_clean )
 
     # Prepare target column
     df_leads_clean = devutils.set_target_column(df=df_leads_clean,model_type=model_type,bins=config['bins'])
